( cd usr/X11R6/lib ; rm -rf libMrm.so )
( cd usr/X11R6/lib ; ln -sf libMrm.so.3.0.1 libMrm.so )
( cd usr/X11R6/lib ; rm -rf libMrm.so.3 )
( cd usr/X11R6/lib ; ln -sf libMrm.so.3.0.1 libMrm.so.3 )
( cd usr/X11R6/lib ; rm -rf libUil.so )
( cd usr/X11R6/lib ; ln -sf libUil.so.3.0.1 libUil.so )
( cd usr/X11R6/lib ; rm -rf libUil.so.3 )
( cd usr/X11R6/lib ; ln -sf libUil.so.3.0.1 libUil.so.3 )
( cd usr/X11R6/lib ; rm -rf libXm.so )
( cd usr/X11R6/lib ; ln -sf libXm.so.3.0.1 libXm.so )
( cd usr/X11R6/lib ; rm -rf libXm.so.3 )
( cd usr/X11R6/lib ; ln -sf libXm.so.3.0.1 libXm.so.3 )
