/* $TOG: ComboBox.h /main/7 1998/02/23 10:32:29 cshi $ */
/*
 *  @OPENGROUP_COPYRIGHT@
 *  COPYRIGHT NOTICE
 *  Copyright (c) 1990, 1991, 1992, 1993 Open Software Foundation, Inc.
 *  Copyright (c) 1996, 1997, 1998, 1999, 2000 The Open Group
 *  ALL RIGHTS RESERVED (MOTIF). See the file named COPYRIGHT.MOTIF for
 *  the full copyright text.
 *  
 *  This software is subject to an open license. It may only be
 *  used on, with or for operating systems which are themselves open
 *  source systems. You must contact The Open Group for a license
 *  allowing distribution and sublicensing of this software on, with,
 *  or for operating systems which are not Open Source programs.
 *  
 *  See http://www.opengroup.org/openmotif/license for full
 *  details of the license agreement. Any use, reproduction, or
 *  distribution of the program constitutes recipient's acceptance of
 *  this agreement.
 *  
 *  EXCEPT AS EXPRESSLY SET FORTH IN THIS AGREEMENT, THE PROGRAM IS
 *  PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, EITHER EXPRESS OR IMPLIED INCLUDING, WITHOUT LIMITATION, ANY
 *  WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT, MERCHANTABILITY
 *  OR FITNESS FOR A PARTICULAR PURPOSE
 *  
 *  EXCEPT AS EXPRESSLY SET FORTH IN THIS AGREEMENT, NEITHER RECIPIENT
 *  NOR ANY CONTRIBUTORS SHALL HAVE ANY LIABILITY FOR ANY DIRECT,
 *  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING WITHOUT LIMITATION LOST PROFITS), HOWEVER CAUSED
 *  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OR DISTRIBUTION OF THE PROGRAM OR THE
 *  EXERCISE OF ANY RIGHTS GRANTED HEREUNDER, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGES.
 */
/*
 * HISTORY
 */
/* ComboBox.h */

#ifndef _XmComboBox_h
#define _XmComboBox_h

#include <Xm/Xm.h>

#ifdef __cplusplus
extern "C" {
#endif

externalref WidgetClass xmComboBoxWidgetClass;

typedef struct _XmComboBoxClassRec	* XmComboBoxWidgetClass;
typedef struct _XmComboBoxRec 		* XmComboBoxWidget;


/* XmIsComboBox may already be defined for Fast Subclassing  */
#ifndef XmIsComboBox
#define XmIsComboBox(w)		XtIsSubclass(w, xmComboBoxWidgetClass)
#endif  /* XmIsComboBox */

/********    Public Function Declarations    ********/

extern Widget XmCreateComboBox (Widget parent, 
				char *name, 
				ArgList args, 
				Cardinal argCount);
extern Widget XmCreateDropDownComboBox (Widget parent, 
					char *name, 
					ArgList args, 
					Cardinal argCount);
extern Widget XmCreateDropDownList (Widget parent, 
				    char *name, 
				    ArgList args, 
				    Cardinal argCount);

extern void XmComboBoxAddItem (Widget   widget,
			       XmString item,
			       int      pos,
			       Boolean  unique);
extern void XmComboBoxDeletePos (Widget widget,
				 int    pos);
extern void XmComboBoxSelectItem (Widget   widget,
				  XmString item);

/* JIM ADDED THIS TO APEASE SYMBOL GOD */
extern XmString  XmCombinationBoxGetValue(Widget widget);

extern void XmComboBoxSetItem (Widget   widget,
			       XmString item);
extern void XmComboBoxUpdate (Widget widget);

/********    End Public Function Declarations    ********/


#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration which encloses file. */
#endif

#endif /* _XmComboBox_h */
/* DON'T ADD ANYTHING AFTER THIS #endif */

